/*******************************************************************************
  Copyright(c) 2000 - 2003 Radu Corlan. All rights reserved.
  
  This program is free software; you can redistribute it and/or modify it 
  under the terms of the GNU General Public License as published by the Free 
  Software Foundation; either version 2 of the License, or (at your option) 
  any later version.
  
  This program is distributed in the hope that it will be useful, but WITHOUT 
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or 
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for 
  more details.
  
  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc., 59 
  Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  
  The full GNU General Public License is included in this distribution in the
  file called LICENSE.
  
  Contact Information: radu@corlan.net
*******************************************************************************/

/* psf analysis and extraction */

#define _GNU_SOURCE
#include <stdio.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <string.h>
#include <stdlib.h>
#include <libgen.h>
#include <math.h>
#include <ctype.h>

#include <gdk/gdkkeysyms.h>
#include <gtk/gtk.h>

#include "gcx.h"
#include "catalogs.h"
#include "gui.h"
#include "interface.h"
#include "params.h"
#include "sourcesdraw.h"
#include "obsdata.h"
#include "recipy.h"
#include "symbols.h"
#include "wcs.h"
#include "multiband.h"
#include "filegui.h"
#include "plots.h"

int growth_curve(struct ccd_frame *fr, double x, double y, double grc[], int n)
{
	struct ap_params apdef;
	struct star s;
	int i, ret;
	double mflux = 1;

	ap_params_from_par(&apdef);

	memset(&s, 0, sizeof(struct star));
	s.x = x;
	s.y = y;
	s.xerr = BIG_ERR;
	s.yerr = BIG_ERR;
	if (P_INT(AP_AUTO_CENTER)) {
		center_star(fr, &s, P_DBL(AP_MAX_CENTER_ERR));
	}
	apdef.center = P_INT(AP_AUTO_CENTER);
	ret = aperture_photometry(fr, &s, &apdef, NULL);
	if (ret)
		return ret;
	apdef.center = 0;

	for (i = 0; i < n; i++) {
		apdef.r1 = 1.0*(i * 0.25 + 1);
		ret = aperture_photometry(fr, &s, &apdef, NULL);
		if (ret)
			return ret;
		grc[i] = s.aph.tflux - s.aph.star_all * s.aph.sky;
		if (grc[i] > mflux)
			mflux = grc[i];
	}
	for (i = 0; i < n; i++) {
		grc[i] /= mflux;
	}	
	return 0;
}



